@@ -4,7 +4,8 @@
 
 """
 
-Name: cli.py
+cli.py
+======
 
 Desc: Command-line tool for listing Python packages installed by setuptools,
       package metadata, package dependencies, and querying The Cheese Shop
@@ -17,6 +18,8 @@ License  : PSF (Python Software Foundation License)
 
 """
 
+__docformat__ = 'restructuredtext'
+
 import sys
 import optparse
 import pkg_resources
@@ -34,6 +37,7 @@ class Usage(Exception):
     """Usage exception"""
 
     def __init__(self, msg):
+        """init"""
         print >> sys.stderr, "%s" % msg
         sys.exit(2)
 
@@ -92,10 +96,10 @@ def show_distributions(show, project_name, version, show_metadata,
     for (dist, active) in dists.get_distributions(show, project_name,
             version):
         metadata = get_metadata(dist)
-        for ignore in ignores:
-            if dist.location.startswith(ignore):
-                dist.location = dist.location.replace(ignore, "")
-        if dist.location.startswith(get_python_lib()):
+        for prefix in ignores:
+            if dist.location.startswith(prefix):
+                dist.location = dist.location.replace(prefix, "")
+        if dist.location.lower().startswith(get_python_lib().lower()):
             develop = ""
         else:
             develop = dist.location
