@@ -4,7 +4,8 @@
 
 """
 
-Name     : metadata.py
+metadata.py
+===========
 
 Author   : Rob Cakebread <gentoodev@gmail.com>
 
@@ -17,6 +18,7 @@ Desc     : Return metadata for Python distribution installed by setuptools
 
 """
 
+__docformat__ = 'restructuredtext'
 
 import email
 
