@@ -4,7 +4,8 @@
 
 """
 
-Name: pypi.py
+pypi.py
+=======
 
 Desc: Library for getting information about Python packages by querying
       The CheeseShop (PYPI a.k.a. Python Package Index).
@@ -16,6 +17,8 @@ License  : PSF (Python Software Foundation License)
 
 """
 
+__docformat__ = 'restructuredtext'
+
 import xmlrpclib
 import cPickle
 import urllib2
@@ -50,6 +53,7 @@ class CheeseShop:
     """Interface to Python Package Index"""
 
     def __init__(self):
+        """init"""
 
         self.yolk_dir = self.get_yolk_dir()
 
